==> gradle-2.14-rc-1-src.zip: gradle-2.14-rc-1/subprojects/dependency-management/src/main/java/org/gradle/api/internal/artifacts/ivyservice/resolveengine/graph/CompositeDependencyArtifactsVisitor.java <==
/*
 * Copyright 2015 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.internal.artifacts.ivyservice.resolveengine.graph;

import org.gradle.api.internal.artifacts.ResolvedConfigurationIdentifier;
import org.gradle.api.internal.artifacts.ivyservice.resolveengine.artifact.ArtifactSet;
import org.gradle.api.internal.artifacts.ivyservice.resolveengine.artifact.DependencyArtifactsVisitor;

import java.util.Arrays;
import java.util.List;

public class CompositeDependencyArtifactsVisitor implements DependencyArtifactsVisitor {
    private final List<DependencyArtifactsVisitor> visitors;

    public CompositeDependencyArtifactsVisitor(DependencyArtifactsVisitor... visitors) {
        this.visitors = Arrays.asList(visitors);
    }

    @Override
    public void visitArtifacts(ResolvedConfigurationIdentifier parent, ResolvedConfigurationIdentifier child, ArtifactSet artifacts) {
        for (DependencyArtifactsVisitor visitor : visitors) {
            visitor.visitArtifacts(parent, child, artifacts);
        }
    }

    @Override
    public void finishArtifacts() {
        for (DependencyArtifactsVisitor visitor : visitors) {
            visitor.finishArtifacts();
        }
    }
}

==> gradle-3.4-rc-1-src.zip: gradle-3.4-rc-1/subprojects/dependency-management/src/main/java/org/gradle/api/internal/artifacts/ivyservice/resolveengine/graph/CompositeDependencyArtifactsVisitor.java <==
/*
 * Copyright 2015 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.api.internal.artifacts.ivyservice.resolveengine.graph;

import org.gradle.api.internal.artifacts.ivyservice.resolveengine.artifact.ArtifactSet;
import org.gradle.api.internal.artifacts.ivyservice.resolveengine.artifact.DependencyArtifactsVisitor;

import java.util.Arrays;
import java.util.List;

public class CompositeDependencyArtifactsVisitor implements DependencyArtifactsVisitor {
    private final List<DependencyArtifactsVisitor> visitors;

    public CompositeDependencyArtifactsVisitor(DependencyArtifactsVisitor... visitors) {
        this.visitors = Arrays.asList(visitors);
    }

    @Override
    public void startArtifacts(DependencyGraphNode root) {
        for (DependencyArtifactsVisitor visitor : visitors) {
            visitor.startArtifacts(root);
        }
    }

    @Override
    public void visitArtifacts(DependencyGraphNode from, DependencyGraphNode to, ArtifactSet artifacts) {
        for (DependencyArtifactsVisitor visitor : visitors) {
            visitor.visitArtifacts(from, to, artifacts);
        }
    }

    @Override
    public void finishArtifacts() {
        for (DependencyArtifactsVisitor visitor : visitors) {
            visitor.finishArtifacts();
        }
    }
}
